==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ButtonGroupSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonGroupSelectionChangedEventArgsDescription } from "./ButtonGroupSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
var ButtonGroupSelectionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ButtonGroupSelectionChangedEventArgsDescriptionMetadata, _super);
    function ButtonGroupSelectionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a == null) {
            ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ButtonGroupSelectionChangedEventArgsDescriptionMetadata.c(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
    };
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.d = function (a) {
        ButtonGroupSelectionChangedEventArgsDescriptionMetadata.b(a);
        a.ac("ButtonGroupSelectionChangedEventArgs", function () { return new ButtonGroupSelectionChangedEventArgsDescription(); });
        a.ab("ButtonGroupSelectionChangedEventArgs", ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
    };
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.$t = markType(ButtonGroupSelectionChangedEventArgsDescriptionMetadata, 'ButtonGroupSelectionChangedEventArgsDescriptionMetadata');
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = null;
    return ButtonGroupSelectionChangedEventArgsDescriptionMetadata;
}(Base));
export { ButtonGroupSelectionChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ButtonGroupSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonGroupSelectionChangedEventArgsDescription } from "./ButtonGroupSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
var ButtonGroupSelectionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ButtonGroupSelectionChangedEventArgsDescriptionMetadata, _super);
    function ButtonGroupSelectionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a == null) {
            ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ButtonGroupSelectionChangedEventArgsDescriptionMetadata.c(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
    };
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.d = function (a) {
        ButtonGroupSelectionChangedEventArgsDescriptionMetadata.b(a);
        a.ae("ButtonGroupSelectionChangedEventArgs", function () { return new ButtonGroupSelectionChangedEventArgsDescription(); });
        a.ad("ButtonGroupSelectionChangedEventArgs", ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
    };
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.$t = markType(ButtonGroupSelectionChangedEventArgsDescriptionMetadata, 'ButtonGroupSelectionChangedEventArgsDescriptionMetadata');
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = null;
    return ButtonGroupSelectionChangedEventArgsDescriptionMetadata;
}(Base));
export { ButtonGroupSelectionChangedEventArgsDescriptionMetadata };
